.. gtrace documentation master file, created by
   sphinx-quickstart on Sun Sep  1 22:19:08 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to gtrace's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   intro
   basic_concepts
   propagation
   tutorial   

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
